@@ -2,16 +2,19 @@
 git-copilot-commit - AI-powered Git commit assistant
 """
 
+import rich.terminal_theme
+import sys
 import typer
 from rich.console import Console
 from rich.prompt import Confirm
 from rich.panel import Panel
 from rich.table import Table
 import rich
+from pathlib import Path
 
-from pycopilot.copilot import Copilot  # type: ignore
+from pycopilot.copilot import Copilot, CopilotAPIError  # type: ignore
 from pycopilot.auth import Authentication
-from .git import GitRepository, GitError, NotAGitRepositoryError, GitStatus
+from .git import GitRepository, GitError, NotAGitRepositoryError
 from .settings import Settings
 from .version import __version__
 
@@ -21,7 +24,7 @@ app = typer.Typer(help=__doc__, add_completion=False)
 
 def version_callback(value: bool):
     if value:
-        rich.print(f"git-copilot-commit [bold green]{__version__}[/]")
+        rich.print(f"git-copilot-commit [bold yellow]{__version__}[/]")
         raise typer.Exit()
 
 
@@ -37,117 +40,108 @@ def main(
     """
     if ctx.invoked_subcommand is None:
         # Show help when no command is provided
-        print(ctx.get_help())
+        console.print(ctx.get_help())
         raise typer.Exit()
+    else:
+        # Don't show version for print command to avoid interfering with pipes
+        if ctx.invoked_subcommand != "echo":
+            console.print(
+                f"[bold]{(__package__ or 'git_copilot_commit').replace('_', '-')}[/] - [bold green]v{__version__}[/]\n"
+            )
+
+
+def get_prompt_locations():
+    """Get potential prompt file locations in order of preference."""
+    import importlib.resources
+
+    filename = "commit-message-generator-prompt.md"
+
+    return [
+        Path(Settings().data_dir) / "prompts" / filename,  # User customizable
+        importlib.resources.files("git_copilot_commit")
+        / "prompts"
+        / filename,  # Packaged version
+    ]
+
+
+def get_active_prompt_path():
+    """Get the path of the prompt file that will be used."""
+    for path in get_prompt_locations():
+        try:
+            path.read_text(encoding="utf-8")
+            return str(path)
+        except (FileNotFoundError, AttributeError):
+            continue
+    return None
+
+
+def load_system_prompt() -> str:
+    """Load the system prompt from the markdown file."""
+    for path in get_prompt_locations():
+        try:
+            return path.read_text(encoding="utf-8")
+        except (FileNotFoundError, AttributeError):
+            continue
+
+    console.print("[red]Error: Prompt file not found in any location[/red]")
+    raise typer.Exit(1)
 
 
 def generate_commit_message(
-    repo: GitRepository, status: GitStatus, model: str | None = None
+    repo: GitRepository, model: str | None = None, context: str = ""
 ) -> str:
     """Generate a conventional commit message using Copilot API."""
 
-    # Get recent commits for context (handle empty repositories)
+    # Refresh status after staging
+    status = repo.get_status()
+
+    if not status.has_staged_changes:
+        console.print("[red]No staged changes to commit.[/red]")
+        raise typer.Exit()
+
+    system_prompt = load_system_prompt()
+    client = Copilot(system_prompt=system_prompt)
+
+    prompt_parts = [
+        "`git status`:\n",
+        f"```\n{status.get_porcelain_output()}\n```",
+        "\n\n`git diff --staged`:\n",
+        f"```\n{status.staged_diff}\n```",
+    ]
+
+    if context.strip():
+        prompt_parts.insert(0, f"User-provided context:\n\n{context.strip()}\n\n")
+
+    prompt_parts.append("\nGenerate a conventional commit message:")
+
+    prompt = "\n".join(prompt_parts)
+
     try:
-        recent_commits = repo.get_recent_commits(limit=5)
-        recent_commits_text = "\n".join([f"- {msg}" for _, msg in recent_commits])
-    except GitError:
-        # No commits yet in this repository
-        recent_commits_text = "No previous commits (initial commit)"
+        response = client.ask(prompt, model=model) if model else client.ask(prompt)
+        return response.content
+    except CopilotAPIError:
+        fallback_prompt_parts = [
+            "`git status`:\n",
+            f"```\n{status.get_porcelain_output()}\n```",
+        ]
 
-    client = Copilot(
-        system_prompt="""
+        if context.strip():
+            fallback_prompt_parts.insert(
+                0, f"User-provided context:\n\n{context.strip()}\n\n"
+            )
 
-You are a Git commit message assistant trained to write a single clear, structured, and informative commit message following the Conventional Commits specification based on the provided `git diff --staged` output.
+        fallback_prompt_parts.append(
+            "\nGenerate a conventional commit message based on the git status above:"
+        )
 
-Output format: Provide only the commit message without any additional text, explanations, or formatting markers.
+        fallback_prompt = "\n".join(fallback_prompt_parts)
 
-The guidelines for the commit messages are as follows:
-
-1. Format
-
-  ```
-  <type>[optional scope]: <description>
-  ```
-
-  - The first line (title) should be at most 72 characters long.
-  - If the natural description exceeds 72 characters, prioritize the most important aspect.
-  - Use abbreviations when appropriate: `config` not `configuration`.
-  - The body (if present) should be wrapped at 100 characters per line.
-
-2. Valid Commit Types:
-
-- `feat`: A new feature
-- `fix`: A bug fix
-- `docs`: Documentation changes
-- `style`: Code formatting (no logic changes)
-- `refactor`: Code restructuring (no behavior changes)
-- `perf`: Performance improvements
-- `test`: Adding or updating tests
-- `chore`: Maintenance tasks (e.g., tooling, CI/CD, dependencies)
-- `revert`: Reverting previous changes
-
-3. Scope (Optional but encouraged):
-
-- Enclose in parentheses
-- Use the affected module, component, or area
-- For multiple files in same area, use the broader scope
-- For single files, you may use filename
-- Scope should be a single word or hyphenated phrase describing the affected module
-
-4. Description:
-
-- Use imperative mood (e.g., "add feature" instead of "added" or "adds").
-- Be concise yet informative.
-- Focus on the primary change, not all details.
-- Do not make assumptions about why the change was made or how it works.
-- When bumping versions, do not mention the names of the files.
-
-5. Analyzing Git Diffs:
-
-- Focus on the logical change, not individual line modifications.
-- Group related file changes under one logical scope.
-- Identify the primary purpose of the change set.
-- If changes span multiple unrelated areas, focus on the most significant one.
-
-❌ Strongly Avoid:
-
-- Vague descriptions: "fixed bug", "updated code", "made changes"
-- Past tense: "added feature", "fixed issue"
-- Explanations of why: "to improve performance", "because users requested"
-- Implementation details: "using React hooks", "with try-catch blocks"
-- Not in imperative mood: "new feature", "updates stuff"
-
-Given a Git diff, a list of modified files, or a short description of changes,
-generate a single, short, clear and structured Conventional Commit message following the above rules.
-If multiple changes are detected, prioritize the most important changes in a single commit message.
-Do not add any body or footer.
-You can only give one reply for each conversation.
-
-Do not wrap the response in triple backticks or single backticks.
-Return the commit message as the output without any additional text, explanations, or formatting markers.
-"""
-    )
-
-    prompt = f"""Recent commits:
-
-{recent_commits_text}
-
-`git status`:
-
-```
-{status.get_porcelain_output()}
-```
-
-`git diff --staged`:
-
-```
-{status.staged_diff}
-```
-
-Generate a conventional commit message:"""
-
-    response = client.ask(prompt, model=model) if model else client.ask(prompt)
-    return response.content
+        response = (
+            client.ask(fallback_prompt, model=model)
+            if model
+            else client.ask(fallback_prompt)
+        )
+        return response.content
 
 
 @app.command()
@@ -161,6 +155,12 @@ def commit(
     yes: bool = typer.Option(
         False, "--yes", "-y", help="Automatically accept the generated commit message"
     ),
+    context: str = typer.Option(
+        "",
+        "--context",
+        "-c",
+        help="Optional user-provided context to guide commit message",
+    ),
 ):
     """
     Generate commit message based on changes in the current git repository and commit them.
@@ -208,25 +208,29 @@ def commit(
                 repo.stage_files()
                 console.print("[green]Staged untracked files.[/green]")
 
-    # Refresh status after staging
-    status = repo.get_status()
-
-    if not status.has_staged_changes:
-        console.print("[yellow]No staged changes to commit.[/yellow]")
-        raise typer.Exit()
+    if context:
+        console.print(
+            Panel(context.strip(), title="User Context", border_style="magenta")
+        )
 
     # Generate or use provided commit message
     with console.status(
-        "[cyan]Generating commit message based on [bold]`git diff --staged`[/bold] ...[/cyan]"
+        "[yellow]Generating commit message based on [bold]`git diff --staged`[/] ...[/yellow]"
     ):
-        commit_message = generate_commit_message(repo, status, model)
+        commit_message = generate_commit_message(repo, model, context=context)
 
     console.print(
-        "[cyan]Generated commit message based on [bold]`git diff --staged`[/bold] ...[/cyan]"
+        "[yellow]Generated commit message based on [bold]`git diff --staged`[/] ...[/yellow]"
     )
 
     # Display commit message
-    console.print(Panel(commit_message, title="Commit Message", border_style="green"))
+    console.print(
+        Panel(
+            f"[bold]{commit_message}[/]",
+            title="Commit Message",
+            border_style="cyan",
+        )
+    )
 
     # Confirm commit or edit message (skip if --yes flag is used)
     if yes:
@@ -332,8 +336,60 @@ def config(
         else:
             console.print("Default model: [dim]not set[/dim]")
 
+        active_prompt = get_active_prompt_path()
+        if active_prompt:
+            console.print(f"Active prompt file: [cyan]{active_prompt}[/cyan]")
+        else:
+            console.print("Active prompt file: [red]not found[/red]")
+
         console.print(f"Config file: [dim]{settings.config_file}[/dim]")
 
 
+@app.command()
+def echo(
+    model: str | None = typer.Option(
+        None, "--model", "-m", help="Model to use for generating commit message"
+    ),
+):
+    """
+    Generate commit message from stdin input (useful for pipes).
+    """
+    # Read from stdin
+    input_text = sys.stdin.read()
+
+    if not input_text.strip():
+        console.print("[red]Error: No input provided via stdin[/red]")
+        raise typer.Exit(1)
+
+    # Load settings and use default model if none provided
+    settings = Settings()
+    if model is None:
+        model = settings.default_model
+
+    # Load system prompt and create client
+    system_prompt = load_system_prompt()
+    client = Copilot(system_prompt=system_prompt)
+
+    # Generate commit message from the input
+    prompt = f"""
+`git diff --staged`:
+
+```
+{input_text.strip()}
+```
+
+Generate a conventional commit message based on the input above:"""
+
+    try:
+        response = client.ask(prompt, model=model) if model else client.ask(prompt)
+        # Print the commit message directly to stdout (no rich formatting for pipes)
+        import builtins
+
+        builtins.print(response.content)
+    except CopilotAPIError as e:
+        console.print(f"[red]Error generating commit message: {e}[/red]")
+        raise typer.Exit(1)
+
+
 if __name__ == "__main__":
     app()
